@@ -2,7 +2,7 @@ package AI::XGBoost;
 use strict;
 use warnings;
 
-our $VERSION = '0.003';    # VERSION
+our $VERSION = '0.004';    # VERSION
 
 # ABSTRACT: Perl wrapper for XGBoost library L<https://github.com/dmlc/xgboost>
 
@@ -20,49 +20,37 @@ AI::XGBoost - Perl wrapper for XGBoost library L<https://github.com/dmlc/xgboost
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
  use 5.010;
- use AI::XGBoost::CAPI;
- use FFI::Platypus;
+ use AI::XGBoost::CAPI qw(:all);
  
- my $silent = 0;
- my ($dtrain, $dtest) = (0, 0);
+ my $dtrain = XGDMatrixCreateFromFile('agaricus.txt.train');
+ my $dtest = XGDMatrixCreateFromFile('agaricus.txt.test');
  
- AI::XGBoost::CAPI::XGDMatrixCreateFromFile('agaricus.txt.test', $silent, \$dtest);
- AI::XGBoost::CAPI::XGDMatrixCreateFromFile('agaricus.txt.train', $silent, \$dtrain);
+ my ($rows, $cols) = (XGDMatrixNumRow($dtrain), XGDMatrixNumCol($dtrain));
+ say "Train dimensions: $rows, $cols";
  
- my ($rows, $cols) = (0, 0);
- AI::XGBoost::CAPI::XGDMatrixNumRow($dtrain, \$rows);
- AI::XGBoost::CAPI::XGDMatrixNumCol($dtrain, \$cols);
- say "Dimensions: $rows, $cols";
- 
- my $booster = 0;
- 
- AI::XGBoost::CAPI::XGBoosterCreate( [$dtrain] , 1, \$booster);
+ my $booster = XGBoosterCreate([$dtrain]);
  
  for my $iter (0 .. 10) {
-     AI::XGBoost::CAPI::XGBoosterUpdateOneIter($booster, $iter, $dtrain);
+     XGBoosterUpdateOneIter($booster, $iter, $dtrain);
  }
  
- my $out_len = 0;
- my $out_result = 0;
+ my $predictions = XGBoosterPredict($booster, $dtest, 0, 0);
+ # say join "\n", @$predictions;
  
- AI::XGBoost::CAPI::XGBoosterPredict($booster, $dtest, 0, 0, \$out_len, \$out_result);
- my $ffi = FFI::Platypus->new();
- my $predictions = $ffi->cast(opaque => "float[$out_len]", $out_result);
- 
- #say join "\n", @$predictions;
- 
- AI::XGBoost::CAPI::XGBoosterFree($booster);
+ XGBoosterFree($booster);
+ XGDMatrixFree($dtrain);
+ XGDMatrixFree($dtest);
 
 =head1 DESCRIPTION
 
 Perl wrapper for XGBoost library. This version only wraps part of the C API.
 
-The documentation can be found in L<AI::XGBoost::CAPI>
+The documentation can be found in L<AI::XGBoost::CAPI::RAW>
 
 Currently this module need the xgboost binary available in your system. 
 I'm going to make an Alien module for xgboost but meanwhile you need to
@@ -78,13 +66,13 @@ The goal is to make a full wrapper for XGBoost.
 
 =item 0.1 
 
-Full raw C API available as AI::XGBoost::CAPI::Raw
+Full raw C API available as L<AI::XGBoost::CAPI::RAW>
 
 =item 0.2 
 
-Full C API "easy" to use, with PDL support as AI::XGBoost::CAPI
+Full C API "easy" to use, with PDL support as L<AI::XGBoost::CAPI>
 
-Easy means clients don't have to use FFI::Platypus or modules dealing
+Easy means clients don't have to use L<FFI::Platypus> or modules dealing
 with C structures
 
 =item 0.3
@@ -95,6 +83,22 @@ Object oriented API Moose based with DMatrix and Booster classes
 
 Complete object oriented API
 
+=item 0.5
+
+Use perl signatures (L<https://metacpan.org/pod/distribution/perl/pod/perlexperiment.pod#Subroutine-signatures>)
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<AI::MXNet>
+
+=item L<FFI::Platypus>
+
+=item L<NativeCall>
+
 =back
 
 =head1 AUTHOR
